@@ -21,7 +21,7 @@
 #ifndef LIKEBACK_H
 #define LIKEBACK_H
 
-#include <ntqobject.h>
+#include <tqobject.h>
 
 class TDEConfig;
 class TDEAboutData;
