@@ -19,18 +19,17 @@
  *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
-#include <ntqsocket.h>
-#include <ntqtextstream.h>
-#include <ntqstringlist.h>
-#include <ntqregexp.h>
-#include "torclient.h"
-#include "tork.h"
-#include "torkconfig.h"
-#include "dndlistview.h"
-#include "functions.h"
+#include <tqdir.h>
+#include <tqsocket.h>
+#include <tqtextstream.h>
+#include <tqstringlist.h>
+#include <tqregexp.h>
+#include <tqtimer.h>
 
-#include <ntqtimer.h>
 #include <tdelocale.h>
 #include <assert.h>
 #include <ntqfile.h>
@@ -40,15 +39,20 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <kstandarddirs.h>
-#include <ntqdir.h>
-#include "crypto.h"
 
-#ifndef EXTERNAL_GEOIP
-# include "GeoIP-1.4.0/libGeoIP/GeoIP.h"
-#else
+#ifdef EXTERNAL_GEOIP
 # include <GeoIP.h>
+#else
+# include "GeoIP-1.4.0/libGeoIP/GeoIP.h"
 #endif
 
+#include "torclient.h"
+#include "tork.h"
+#include "torkconfig.h"
+#include "dndlistview.h"
+#include "functions.h"
+#include "crypto.h"
+
 /* Linux-specific includes */
 #include <dirent.h>
 #include <unistd.h>
@@ -374,7 +378,7 @@ void TorClient::authenticate()
         if (TorkConfig::generateRandomPassword()){
             crypto_seed_rng();
             sendToServer(TQString("setconf HashedControlPassword=16:%2")
-                         .arg(hashPassword(crypto_rand_string(16))));
+                         .arg(hashPassword(crypto_rand_string(16).latin1())));
         }
     }
 
@@ -827,15 +831,15 @@ void TorClient::parseServer(const TQString &info)
         GeoIP * gi = 0;
 
         if (geoip_db)
-#ifndef EXTERNAL_GEOIP
-            gi = GeoIP_open(locate("data", "tork/geoip/GeoIP.dat").ascii(),0);
-#else
+#ifdef EXTERNAL_GEOIP
             gi = GeoIP_new(GEOIP_STANDARD);
+#else
+            gi = GeoIP_open(locate("data", "tork/geoip/GeoIP.dat").ascii(),0);
 #endif
 
         if (gi){
             int country_id = 0;
-            country_id = GeoIP_id_by_name(gi, ip);
+            country_id = GeoIP_id_by_name(gi, ip.latin1());
             cc = GeoIP_country_name[country_id];
             GeoIP_delete(gi);
         }else
@@ -1254,7 +1258,7 @@ bool TorClient::noSpecialProcessing(const TDEConfigSkeletonItem* it)
             crypto_seed_rng();
             sendToServer(TQString("setconf %1=16:%2")
                          .arg((*it).name())
-                         .arg(hashPassword(crypto_rand_string(16))));
+                         .arg(hashPassword(crypto_rand_string(16).latin1())));
             return false; 
         }
         return true;
